@@ -20,12 +20,10 @@
 
 from __future__ import annotations
 
-from typing import TypeVar
+from typing import Self
 
 from kraken.base_api import SpotClient, defined
 
-Self = TypeVar("Self")
-
 
 class Funding(SpotClient):
     """
