@@ -21,12 +21,10 @@
 from __future__ import annotations
 
 from functools import lru_cache
-from typing import TypeVar
+from typing import Self
 
 from kraken.base_api import SpotClient, defined, ensure_string
 
-Self = TypeVar("Self")
-
 
 class Market(SpotClient):
     """
