@@ -24,12 +24,10 @@
 from __future__ import annotations
 
 from decimal import Decimal
-from typing import TypeVar
+from typing import Self
 
 from kraken.base_api import SpotClient, defined, ensure_string
 
-Self = TypeVar("Self")
-
 
 class User(SpotClient):
     """
