@@ -165,7 +165,7 @@ class ConnectSpotWebsocketBase:  # pylint: disable=too-many-instance-attributes
                 if time() - self._last_ping > self.PING_INTERVAL:
                     await self.send_ping()
                 try:
-                    _message = await asyncio.wait_for(self.socket.recv(), timeout=10)
+                    data = await asyncio.wait_for(self.socket.recv(), timeout=10)
                 except TimeoutError:  # important
                     await self.send_ping()
                 except asyncio.CancelledError:
@@ -173,9 +173,9 @@ class ConnectSpotWebsocketBase:  # pylint: disable=too-many-instance-attributes
                     self.keep_alive = False
                 else:
                     try:
-                        message: dict = json.loads(_message)
+                        message: dict = json.loads(data)
                     except ValueError:
-                        LOG.warning(_message)
+                        LOG.warning(data)
                     else:
                         LOG.debug(message)
                         self._manage_subscriptions(message=message)
@@ -245,8 +245,13 @@ class ConnectSpotWebsocketBase:  # pylint: disable=too-many-instance-attributes
                 if task.exception():
                     self.state = WSState.ERRORHANDLING
                     exception_occur = True
-                    message = f"{task} got an exception {task.exception()}\n {task.get_stack()}"
-                    LOG.warning(message)
+                    LOG.warning(
+                        "%s got an exception %s:\n%s\n"
+                        "The connection will be recovered in the background.",
+                        task,
+                        task.exception(),
+                        task.get_stack(),
+                    )
                     for process in pending:
                         LOG.warning("pending %s", process)
                         try:
@@ -254,7 +259,6 @@ class ConnectSpotWebsocketBase:  # pylint: disable=too-many-instance-attributes
                             LOG.warning("Cancelled %s", process)
                         except asyncio.CancelledError:
                             LOG.error("Failed to cancel %s", process)
-                    await self.__callback({"python-kraken-sdk": {"error": message}})
             if exception_occur:
                 break
         self.state = WSState.CLOSED
